function getServerLanguage(localeId, supportedLanguages) {
  var chineseCodeMain = 'zh';
  for (var index = 0; index < supportedLanguages.length; index++) {
    var pair = supportedLanguages[index];
    var lang = pair.value.substring(0, 2);
    var mainLocalId = localeId.substring(0, 2);
    if (mainLocalId !== chineseCodeMain && mainLocalId === lang) {
      return lang;
    } else if (mainLocalId === chineseCodeMain) {
      var chSubCode = 'TW';//Traditional
      var locale = localeId.toUpperCase().substring(3);//remove zh_ or zh- from language name
      var localIdSub = locale.substring(0, chSubCode.length);
      if (localIdSub !== chSubCode) {
        chSubCode = 'CN';// set Chinese Simplified by default to all chinese codes other than Traditional
      }
      return chineseCodeMain + '_' + chSubCode;
    }
  }
  return 'en';//if nothing found fall back to English
}

const languageOptions = [
  { value: 'en', text: 'English' },
  { value: 'de', text: 'Deutsch' },
  { value: 'es', text: 'Español' },
  { value: 'fr', text: 'Français' },
  { value: 'it', text: 'Italiano' },
  { value: 'ja', text: '日本語' },
  { value: 'pt', text: 'Português-Brasil' },
  { value: 'ru', text: 'Русский' },
  { value: 'pl', text: 'Polski' },
  { value: 'zh_TW', text: '中文(繁體)' },
  { value: 'zh_CN', text: '中文(简体)' },
  { value: 'cs', text: 'Čeština' },
  { value: 'hu', text: 'Magyar' },
  { value: 'sk', text: 'Slovak' }
];

var languageStrings = {};

document.addEventListener('DOMContentLoaded', function () {
  var userLang = navigator.language || navigator.userLanguage;
  var lang = getServerLanguage(userLang, languageOptions);
  localStorage.setItem("lang", lang)
  let url = '/storm/resources/strings/Strings_' + lang + '.json';
  let urlEn = '/storm/resources/strings/Strings_en.json';

  axios.get(url)
    .then(function (response) {
      languageStrings = response.data;
      axios.get(urlEn)
        .then(function (response) {
          Strings = response.data
          for (var key in languageStrings) {
            Strings[key] = languageStrings[key];
          }
          localStorage.setItem('strings', JSON.stringify(Strings))
        })
      document.getElementById('j_username').placeholder=response.data.USER_NAME;
      document.getElementById('j_password').placeholder=response.data.PASSWORD;
      document.getElementsByClassName('loginButton')[0].innerHTML=response.data.LOGIN;
      var errorLogin = document.querySelector('input[name=\'login_fail\']');
      if (errorLogin != null) {
        var springErrSig = errorLogin.value;
        var errStr = null;
        if (springErrSig == 'invalid_credentials') {
          errStr = response.data.LOGIN_FAILED;
        }
        else if (springErrSig == 'service_locked') {
          errStr = response.data.SERVICE_LOCKED;
        }
        else if (springErrSig == 'invalid_login_format') {
          errStr = response.data.INVALID_LOGIN_FORMAT;
        }
        var ele = document.getElementsByClassName('failedLogin');
        ele[0].innerHTML = errStr;
      }
    })
    .catch(function(err) {
      document.getElementsByClassName('failedLogin')[0].innerHTML = err;
    });
});
